Package: lfda
Type: Package
Title: Local Fisher Discriminant Analysis
Version: 1.1.3
Date: 2019-07-31
Authors@R: c(
  person("Yuan", "Tang", role = c("aut", "cre"),
         email = "terrytangyuan@gmail.com",
         comment = c(ORCID = "0000-0001-5243-233X")),
  person("Wenxuan", "Li", role = c("ctb")),
  person("Nan", "Xiao", role = c("ctb", "cph")),
  person("Zachary", "Deane-Mayer", role = c("ctb")))
URL: https://github.com/terrytangyuan/lfda
BugReports: https://github.com/terrytangyuan/lfda/issues
Maintainer: Yuan Tang <terrytangyuan@gmail.com>
License: MIT + file LICENSE
Description: Functions for performing and visualizing Local Fisher Discriminant
    Analysis(LFDA), Kernel Fisher Discriminant Analysis(KLFDA), and Semi-supervised
    Local Fisher Discriminant Analysis(SELF).
Depends: R (>= 3.1.0)
Imports: plyr, grDevices, rARPACK
Suggests: testthat, rgl
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2019-07-31 16:46:28 UTC; yuan.tang
Author: Yuan Tang [aut, cre] (<https://orcid.org/0000-0001-5243-233X>),
  Wenxuan Li [ctb],
  Nan Xiao [ctb, cph],
  Zachary Deane-Mayer [ctb]
Repository: CRAN
Date/Publication: 2019-07-31 17:10:02 UTC
Built: R 4.6.0; ; 2026-04-27 07:03:34 UTC; unix
