Package: lfda
Type: Package
Title: Local Fisher Discriminant Analysis
Version: 1.1.3
Date: 2019-07-26
Author: Yuan Tang. Contributions from Wenxuan Li, Nan Xiao and Zachary Deane-Mayer.
URL: https://github.com/terrytangyuan/lfda
BugReports: https://github.com/terrytangyuan/lfda/issues
Maintainer: Yuan Tang <terrytangyuan@gmail.com>
License: MIT + file LICENSE
Description: Functions for performing and visualizing Local Fisher Discriminant
    Analysis(LFDA), Kernel Fisher Discriminant Analysis(KLFDA), and Semi-supervised
    Local Fisher Discriminant Analysis(SELF).
Depends: R (>= 3.1.0)
Imports: plyr, grDevices, rARPACK
Suggests: testthat, rgl
RoxygenNote: 6.1.0
Built: R 4.4.0; ; 2024-05-03 03:23:49 UTC; unix
